@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 14.04's 3.13 kernel.
+# This is kernel build script for ubuntu 12.04's 3.2 kernel.
 #
 
 update_maintainer () {
@@ -18,7 +18,7 @@ die () {
     exit 1
 }
 
-ORIGINAL_FLAVOUR=`uname -r | cut -d - -f 3- | sed -e 's/generic-pae/generic/'` # e.g. generic server
+ORIGINAL_FLAVOUR=`uname -r | cut -d - -f 3-` # e.g. generic generic-pae server
 NEW_FLAVOUR=${ORIGINAL_FLAVOUR}-cs
 echo "Building "${NEW_FLAVOUR}" from "${ORIGINAL_FLAVOUR}"."
 
@@ -29,24 +29,24 @@ apt-get -y install wget
 # Download CaitSith patches.
 mkdir -p ~/rpmbuild/SOURCES/
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r caitsith-patch-0.2-20230527.tar.gz ]
+if [ ! -r caitsith-patch-0.2-20231111.tar.gz ]
 then
-    wget -O caitsith-patch-0.2-20230527.tar.gz 'https://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20230527.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.2-20231111.tar.gz 'https://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20231111.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
 apt-get -y install fakeroot build-essential || die "Can't install packages."
 apt-get build-dep linux || die "Can't install packages."
-apt-get source linux-source-3.13.0 || die "Can't install kernel source."
-for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-3.13.0/debian/control`; do apt-get -y install $i; done
+apt-get source linux-source-3.2.0 || die "Can't install kernel source."
+for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-3.2.0/debian/control`; do apt-get -y install $i; done
 
 # Apply patches and create kernel config.
-cd linux-3.13.0/ || die "Can't chdir to linux-3.13.0/ ."
+cd linux-3.2.0/ || die "Can't chdir to linux-3.2.0/ ."
 update_maintainer
-tar -zxf ~/rpmbuild/SOURCES/caitsith-patch-0.2-20230527.tar.gz || die "Can't extract patch."
+tar -zxf ~/rpmbuild/SOURCES/caitsith-patch-0.2-20231111.tar.gz || die "Can't extract patch."
 sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
-patch -p1 < patches/ccs-patch-3.13-ubuntu-14.04.diff || die "Can't apply patch."
+patch -p1 < patches/ccs-patch-3.2-ubuntu-12.04.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*'${ORIGINAL_FLAVOUR}'*'`; do cp -p $i `echo $i | sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g'`; done
 for i in debian.master/config/*/config.common.*; do cat config.caitsith >> $i; done
