@@ -56,6 +56,12 @@ static int __init cs_init(void)
 	if (!ptr)
 		goto out;
 	printk(KERN_INFO "ksize=%lx\n", (unsigned long) ptr);
+#endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+	ptr = probe_copy_to_kernel_nofault();
+	if (!ptr)
+		goto out;
+	printk(KERN_INFO "copy_to_kernel_nofault=%lx\n", (unsigned long) ptr);
 #endif
 	printk(KERN_INFO "All dependent symbols have been guessed.\n");
 	printk(KERN_INFO "Please verify these addresses using System.map for this kernel (e.g. /boot/System.map-`uname -r` ).\n");
